@@ -585,6 +585,8 @@ def FormatMembershipOptions(mlist, cgi_data):
             chunk = 0
         else:
             chunk = string.atoi(cgi_data["chunk"].value)
+        # Sanitize the chunk
+        chunk = min(len(chunks)-1, max(chunk, 0))
         all = chunks[chunk]
         footer = ("<p><em>To View other sections, "
                   "click on the appropriate range listed below</em>")
